@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: rpcs32.cc,v 1.14 2002/07/14 19:07:04 felfert Exp $
+ * $Id: rpcs32.cc,v 1.15 2003/02/05 07:59:08 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -24,19 +24,17 @@
 #include "config.h"
 #endif
 
-#include <stream.h>
-#include <stdio.h>
-#include <stdlib.h>
-#include <fstream.h>
-#include <iomanip.h>
-#include <time.h>
-#include <string.h>
-
 #include "rpcs32.h"
 #include "bufferstore.h"
 #include "bufferarray.h"
 #include "ppsocket.h"
 
+#include <iostream>
+
+#include <stdio.h>
+#include <stdlib.h>
+#include <time.h>
+
 using namespace std;
 
 rpcs32::rpcs32(ppsocket * _skt)
