@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: main.cc,v 1.28 2002/08/06 02:02:53 felfert Exp $
+ * $Id: main.cc,v 1.29 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,9 +25,15 @@
 #include "config.h"
 #endif
 
-#include <stdio.h>
 #include <string>
-#include <stream.h>
+#include <iostream>
+
+#include <bufferstore.h>
+#include <ppsocket.h>
+#include <iowatch.h>
+#include <log.h>
+
+#include <stdio.h>
 #include <stdlib.h>
 #include <signal.h>
 #include <errno.h>
@@ -38,14 +44,10 @@
 #include <plpintl.h>
 
 #include "ncp.h"
-#include "bufferstore.h"
-#include "ppsocket.h"
 #include "socketchan.h"
-#include "iowatch.h"
 #include "linkchan.h"
 #include "link.h"
 #include "packet.h"
-#include "log.h"
 
 #ifndef _GNU_SOURCE
 #define _GNU_SOURCE
