@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: ncp.cc,v 1.22 2002/07/16 19:40:29 felfert Exp $
+ * $Id: ncp.cc,v 1.23 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -25,8 +25,9 @@
 #include <config.h>
 #endif
 
-#include <stream.h>
+#include <iostream>
 #include <string>
+
 #include <time.h>
 
 #include <bufferstore.h>
