@@ -1,5 +1,5 @@
 /*-*-c++-*-
- * $Id: ftp.cc,v 1.38 2002/07/14 06:35:33 felfert Exp $
+ * $Id: ftp.cc,v 1.39 2003/02/05 07:59:09 felfert Exp $
  *
  * This file is part of plptools.
  *
@@ -27,26 +27,28 @@
 #include "config.h"
 #endif
 
-#include <sys/types.h>
-#include <dirent.h>
-#include <stream.h>
-#include <fstream.h>
-#include <string.h>
-#include <ctype.h>
-#include <stdlib.h>
-#include <stdio.h>
-#include <iomanip.h>
-#include <unistd.h>
-#include <sys/time.h>
-#include <sys/stat.h>
-#include <signal.h>
-
 #include <plpintl.h>
 #include <rfsv.h>
 #include <rpcs.h>
 #include <bufferarray.h>
 #include <bufferstore.h>
 #include <Enum.h>
+
+#include <iostream>
+#include <fstream>
+#include <string>
+#include <iomanip>
+
+#include <sys/types.h>
+#include <dirent.h>
+#include <ctype.h>
+#include <stdlib.h>
+#include <stdio.h>
+#include <unistd.h>
+#include <sys/time.h>
+#include <sys/stat.h>
+#include <signal.h>
+
 #include "ftp.h"
 
 #if HAVE_LIBREADLINE
